TriMesh

Struct TriMesh 

pub struct TriMesh {
    pub triangles: Vec<Triangle>,
}
A Mesh made up of triangles

Fields

triangles: Vec<Triangle>

Implementations

Source

impl TriMesh

pub fn subdivide(&self) -> Self

Subdivides every triangle into 4 other triangles

pub fn separate_by_loose_parts(self) -> Vec<Self>

Seperates any loose parts into there own mesh

Source

impl TriMesh

pub fn new(triangles: Vec<Triangle>) -> Self

pub fn add(&mut self, triangle: Triangle)

adds a triangle to the mesh

pub fn remove(&mut self, index: usize) -> Triangle

removes a triangle at index from the mesh

pub fn tricount(&self) -> usize

returns the amount of triangles this mesh has

pub fn max(&self) -> Vec3

returns a point with the maximum x, y and z values

pub fn min(&self) -> Vec3

returns a point with the minimum x, y, and z values

pub fn surface_area(&self) -> f32

Calculates the surface area of this mesh